==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/keyvault/kotlin/outputs/GetManagedHsmResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.keyvault.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map

/**
 * Resource information with extended details.
 * @property id The Azure Resource Manager resource ID for the managed HSM Pool.
 * @property location The supported Azure location where the managed HSM Pool should be created.
 * @property name The name of the managed HSM Pool.
 * @property properties Properties of the managed HSM
 * @property sku SKU details
 * @property systemData Metadata pertaining to creation and last modification of the key vault resource.
 * @property tags Resource tags
 * @property type The resource type of the managed HSM Pool.
 */
public data class GetManagedHsmResult(
    public val id: String,
    public val location: String? = null,
    public val name: String,
    public val properties: ManagedHsmPropertiesResponse,
    public val sku: ManagedHsmSkuResponse? = null,
    public val systemData: SystemDataResponse,
    public val tags: Map<String, String>? = null,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.keyvault.outputs.GetManagedHsmResult):
            GetManagedHsmResult = GetManagedHsmResult(
            id = javaType.id(),
            location = javaType.location().map({ args0 -> args0 }).orElse(null),
            name = javaType.name(),
            properties = javaType.properties().let({ args0 ->
                com.pulumi.azurenative.keyvault.kotlin.outputs.ManagedHsmPropertiesResponse.Companion.toKotlin(args0)
            }),
            sku = javaType.sku().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.keyvault.kotlin.outputs.ManagedHsmSkuResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.keyvault.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            type = javaType.type(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/keyvault/kotlin/outputs/GetManagedHsmResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.keyvault.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map

/**
 * Resource information with extended details.
 * @property id The Azure Resource Manager resource ID for the managed HSM Pool.
 * @property location The supported Azure location where the managed HSM Pool should be created.
 * @property name The name of the managed HSM Pool.
 * @property properties Properties of the managed HSM
 * @property sku SKU details
 * @property systemData Metadata pertaining to creation and last modification of the key vault resource.
 * @property tags Resource tags
 * @property type The resource type of the managed HSM Pool.
 */
public data class GetManagedHsmResult(
    public val id: String,
    public val location: String? = null,
    public val name: String,
    public val properties: ManagedHsmPropertiesResponse,
    public val sku: ManagedHsmSkuResponse? = null,
    public val systemData: SystemDataResponse,
    public val tags: Map<String, String>? = null,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.keyvault.outputs.GetManagedHsmResult): GetManagedHsmResult = GetManagedHsmResult(
            id = javaType.id(),
            location = javaType.location().map({ args0 -> args0 }).orElse(null),
            name = javaType.name(),
            properties = javaType.properties().let({ args0 ->
                com.pulumi.azurenative.keyvault.kotlin.outputs.ManagedHsmPropertiesResponse.Companion.toKotlin(args0)
            }),
            sku = javaType.sku().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.keyvault.kotlin.outputs.ManagedHsmSkuResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.keyvault.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            type = javaType.type(),
        )
    }
}
